==> ext-system-test-0.8.0.1-sources.jar: org/bluestemsoftware/open/eoa/test/system/feature/HTTPTransportFeatureFactoryProvider.java <==
/**
 * Copyright 2008 Bluestem Software LLC.  All Rights Reserved.
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * 
 */

package org.bluestemsoftware.open.eoa.test.system.feature;

import java.lang.reflect.Method;

import org.bluestemsoftware.open.eoa.test.system.util.MockExtensionProviderFactory;
import org.bluestemsoftware.specification.eoa.ext.ExtensionException;
import org.bluestemsoftware.specification.eoa.ext.feature.FeatureException;
import org.bluestemsoftware.specification.eoa.ext.feature.FeatureFactory;
import org.bluestemsoftware.specification.eoa.ext.feature.ws.transport.http.HTTPTransportFeature;
import org.bluestemsoftware.specification.eoa.ext.feature.ws.transport.http.HTTPTransportFeatureFactory;

public class HTTPTransportFeatureFactoryProvider extends AbstractFeatureFactoryProvider implements HTTPTransportFeatureFactory.Provider {

    public static final String NAME = "http-transport-test";
    
    public HTTPTransportFeatureFactoryProvider(MockExtensionProviderFactory mockExtensionProviderFactory) {
        super(mockExtensionProviderFactory);
    }
    
    /*
     * (non-Javadoc)
     * @see org.bluestemsoftware.specification.eoa.ext.ExtensionFactory$Provider#spi_getName()
     */
    public String spi_getName() {
        return NAME;
    }

    /*
     * (non-Javadoc)
     * @see org.bluestemsoftware.specification.eoa.ext.ExtensionFactory$Provider#spi_getExtensionType()
     */
    public String spi_getExtensionType() {
        return HTTPTransportFeature.TYPE;
    }

    /*
     * (non-Javadoc)
     * @see org.bluestemsoftware.specification.eoa.ext.feature.om.axiom.WSMexFeatureFactory$Provider#spi_createFeature()
     */
    public HTTPTransportFeature.Provider spi_createFeature() throws FeatureException {
        Class<?>[] signature = new Class[] {};
        Method method = null;
        try {
            method = FeatureFactory.Provider.class.getMethod("spi_createFeature", signature);
        } catch (Exception fatchance) {
        }
        Object[] args = new Object[] {};
        try {
            return (HTTPTransportFeature.Provider)mockExtensionProviderFactory.createExtensionProvider(method, args);
        } catch (ExtensionException ex) {
            throw new FeatureException(ex);
        }
    }
        
}

==> ext-system-test-0.8.5.0-sources.jar: org/bluestemsoftware/open/eoa/test/system/feature/HTTPTransportFeatureFactoryProvider.java <==
/**
 * Copyright 2008 Bluestem Software LLC.  All Rights Reserved.
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * 
 */

package org.bluestemsoftware.open.eoa.test.system.feature;

import java.lang.reflect.Method;

import org.bluestemsoftware.open.eoa.test.system.dependency.FeatureDependencyImpl;
import org.bluestemsoftware.open.eoa.test.system.util.MockExtensionProviderFactory;
import org.bluestemsoftware.specification.eoa.ext.ExtensionException;
import org.bluestemsoftware.specification.eoa.ext.feature.FeatureException;
import org.bluestemsoftware.specification.eoa.ext.feature.FeatureFactory;
import org.bluestemsoftware.specification.eoa.ext.feature.ws.transport.http.HTTPTransportFeature;
import org.bluestemsoftware.specification.eoa.ext.feature.ws.transport.http.HTTPTransportFeatureFactory;

/**
 * Wraps a user provided instance of {@link MockExtensionProviderFactory} which
 * facilitates the creation of mock/stubbed instances of {@link HTTPTransportFeature.Provider}
 * used within the context of a test.  See documentation for usage examples.
 * 
 * @see FeatureDependencyImpl
 */

public class HTTPTransportFeatureFactoryProvider extends AbstractFeatureFactoryProvider implements HTTPTransportFeatureFactory.Provider {

    public static final String NAME = "http-transport-test";
    
    public HTTPTransportFeatureFactoryProvider(MockExtensionProviderFactory mockExtensionProviderFactory) {
        super(mockExtensionProviderFactory);
    }
    
    /*
     * (non-Javadoc)
     * @see org.bluestemsoftware.specification.eoa.ext.ExtensionFactory$Provider#spi_getName()
     */
    public String spi_getName() {
        return NAME;
    }

    /*
     * (non-Javadoc)
     * @see org.bluestemsoftware.specification.eoa.ext.ExtensionFactory$Provider#spi_getExtensionType()
     */
    public String spi_getExtensionType() {
        return HTTPTransportFeature.TYPE;
    }

    /*
     * (non-Javadoc)
     * @see org.bluestemsoftware.specification.eoa.ext.feature.om.axiom.WSMexFeatureFactory$Provider#spi_createFeature()
     */
    public HTTPTransportFeature.Provider spi_createFeature() throws FeatureException {
        Class<?>[] signature = new Class[] {};
        Method method = null;
        try {
            method = FeatureFactory.Provider.class.getMethod("spi_createFeature", signature);
        } catch (Exception fatchance) {
        }
        Object[] args = new Object[] {};
        try {
            return (HTTPTransportFeature.Provider)mockExtensionProviderFactory.createExtensionProvider(method, args);
        } catch (ExtensionException ex) {
            throw new FeatureException(ex);
        }
    }
        
}
